@@ -40,7 +40,7 @@ The dialog presents three buttons as follows:
 
 =over 4
 
-=item B<Cancel>: hides the dialog without further processing or interaction.
+=item B<Cancel>: hides the dialog without further processing.
 
 =item B<Exit>: calls the defined exit routine.  See L<CALLBACKS>.
 
@@ -48,6 +48,9 @@ The dialog presents three buttons as follows:
 
 =back
 
+These button labels may be overridden using the B<-buttons> and 
+B<-default_button> arguments (refer to the L<Tk::DialogBox> widget for detail).
+
 =cut
 
 use 5.010001;
@@ -81,7 +84,7 @@ use constant S_WHATAMI => "Tk::DBI::LoginDialog";
 
 
 # --- package globals ---
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 
 
 # --- package locals ---
@@ -782,7 +785,12 @@ sub login {
 		my $button = $self->Show;
 
 		last if (defined $self->dbh);
-		last if (defined $button && $button eq "Cancel");
+
+		if (defined $button) {
+			my $button_id = $self->_button($button);
+
+			last if ($button_id eq "button"); # 'Cancel' button
+		}
 	} 
 
 	return $self->dbh;
@@ -855,11 +863,11 @@ __END__
 
 =head1 VERSION
 
-Build V1.005
+Build V1.006
 
 =head1 AUTHOR
 
-Copyright (C) 2014  B<Tom McMeekin> E<lt>tmcmeeki@cpan.orgE<gt>
+Copyright (C) 2014-2016  B<Tom McMeekin> E<lt>tmcmeeki@cpan.orgE<gt>
 
 =head1 LICENSE
 
@@ -879,7 +887,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 =head1 SEE ALSO
 
-L<perl>, L<DBI>, L<Tk>, L<Tk::DialogBox>.
+L<perl>, L<DBI>, L<Log::Log4perl>, L<Tk>, L<Tk::DialogBox>.
 
 =cut
 
